==> knative-model-5.3.1-sources.jar: annotations/io/fabric8/knative/eventing/contrib/gitlab/v1alpha1/GitLabBindingSpecFluentImpl.java <==
package io.fabric8.knative.eventing.contrib.gitlab.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.knative.internal.pkg.tracker.Reference;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import io.fabric8.knative.internal.pkg.tracker.ReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import io.fabric8.knative.internal.pkg.tracker.ReferenceFluentImpl;

public class GitLabBindingSpecFluentImpl<A extends GitLabBindingSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements GitLabBindingSpecFluent<A> {

    private io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSourceBuilder accessToken;
    private ReferenceBuilder subject;

    public GitLabBindingSpecFluentImpl() {
    }

    public GitLabBindingSpecFluentImpl(GitLabBindingSpec instance) {
        this.withAccessToken(instance.getAccessToken()); 
        this.withSubject(instance.getSubject()); 
    }

    
/**
 * This method has been deprecated, please use method buildAccessToken instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSource getAccessToken() {
        return this.accessToken!=null?this.accessToken.build():null;
    }

    public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSource buildAccessToken() {
        return this.accessToken!=null?this.accessToken.build():null;
    }

    public A withAccessToken(io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSource accessToken) {
        _visitables.get("accessToken").remove(this.accessToken);
        if (accessToken!=null){ this.accessToken= new io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSourceBuilder(accessToken); _visitables.get("accessToken").add(this.accessToken);} return (A) this;
    }

    public Boolean hasAccessToken() {
        return this.accessToken != null;
    }

    public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluent.AccessTokenNested<A> withNewAccessToken() {
        return new AccessTokenNestedImpl();
    }

    public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluent.AccessTokenNested<A> withNewAccessTokenLike(io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSource item) {
        return new AccessTokenNestedImpl(item);
    }

    public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluent.AccessTokenNested<A> editAccessToken() {
        return withNewAccessTokenLike(getAccessToken());
    }

    public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluent.AccessTokenNested<A> editOrNewAccessToken() {
        return withNewAccessTokenLike(getAccessToken() != null ? getAccessToken(): new io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSourceBuilder().build());
    }

    public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluent.AccessTokenNested<A> editOrNewAccessTokenLike(io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSource item) {
        return withNewAccessTokenLike(getAccessToken() != null ? getAccessToken(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSubject instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.knative.internal.pkg.tracker.Reference getSubject() {
        return this.subject!=null?this.subject.build():null;
    }

    public io.fabric8.knative.internal.pkg.tracker.Reference buildSubject() {
        return this.subject!=null?this.subject.build():null;
    }

    public A withSubject(io.fabric8.knative.internal.pkg.tracker.Reference subject) {
        _visitables.get("subject").remove(this.subject);
        if (subject!=null){ this.subject= new ReferenceBuilder(subject); _visitables.get("subject").add(this.subject);} return (A) this;
    }

    public Boolean hasSubject() {
        return this.subject != null;
    }

    public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluent.SubjectNested<A> withNewSubject() {
        return new SubjectNestedImpl();
    }

    public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluent.SubjectNested<A> withNewSubjectLike(io.fabric8.knative.internal.pkg.tracker.Reference item) {
        return new SubjectNestedImpl(item);
    }

    public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluent.SubjectNested<A> editSubject() {
        return withNewSubjectLike(getSubject());
    }

    public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluent.SubjectNested<A> editOrNewSubject() {
        return withNewSubjectLike(getSubject() != null ? getSubject(): new ReferenceBuilder().build());
    }

    public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluent.SubjectNested<A> editOrNewSubjectLike(io.fabric8.knative.internal.pkg.tracker.Reference item) {
        return withNewSubjectLike(getSubject() != null ? getSubject(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        GitLabBindingSpecFluentImpl that = (GitLabBindingSpecFluentImpl) o;
        if (accessToken != null ? !accessToken.equals(that.accessToken) :that.accessToken != null) return false;
        if (subject != null ? !subject.equals(that.subject) :that.subject != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(accessToken,  subject,  super.hashCode());
    }

    public class AccessTokenNestedImpl<N> extends io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSourceFluentImpl<io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluent.AccessTokenNested<N>> implements io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluent.AccessTokenNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSourceBuilder builder;

            AccessTokenNestedImpl(io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSource item) {
                this.builder = new io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSourceBuilder(this, item);
                        
            }

            AccessTokenNestedImpl() {
                this.builder = new io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSourceBuilder(this);
                        
            }

            public N and() {
                return (N) GitLabBindingSpecFluentImpl.this.withAccessToken(builder.build());
            }

            public N endAccessToken() {
                return and();
            }
    }


    public class SubjectNestedImpl<N> extends ReferenceFluentImpl<io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluent.SubjectNested<N>> implements io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluent.SubjectNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final ReferenceBuilder builder;

            SubjectNestedImpl(io.fabric8.knative.internal.pkg.tracker.Reference item) {
                this.builder = new ReferenceBuilder(this, item);
                        
            }

            SubjectNestedImpl() {
                this.builder = new ReferenceBuilder(this);
                        
            }

            public N and() {
                return (N) GitLabBindingSpecFluentImpl.this.withSubject(builder.build());
            }

            public N endSubject() {
                return and();
            }
    }


}

==> knative-model-5.7.1-sources.jar: annotations/io/fabric8/knative/eventing/contrib/gitlab/v1alpha1/GitLabBindingSpecFluentImpl.java <==
package io.fabric8.knative.eventing.contrib.gitlab.v1alpha1;

import io.fabric8.knative.internal.pkg.tracker.Reference;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import io.fabric8.knative.internal.pkg.tracker.ReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import io.fabric8.knative.internal.pkg.tracker.ReferenceFluentImpl;

public class GitLabBindingSpecFluentImpl<A extends io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluent<A> {

    private io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSourceBuilder accessToken;
    private io.fabric8.knative.internal.pkg.tracker.ReferenceBuilder subject;

    public GitLabBindingSpecFluentImpl() {
    }

    public GitLabBindingSpecFluentImpl(io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpec instance) {
        this.withAccessToken(instance.getAccessToken()); 
        this.withSubject(instance.getSubject()); 
    }

    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildAccessToken instead.
     * @return The buildable object.
     */
        public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSource getAccessToken() {
        return this.accessToken!=null?this.accessToken.build():null;
    }

    public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSource buildAccessToken() {
        return this.accessToken!=null?this.accessToken.build():null;
    }

    public A withAccessToken(io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSource accessToken) {
        _visitables.get("accessToken").remove(this.accessToken);
        if (accessToken!=null){ this.accessToken= new io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSourceBuilder(accessToken); _visitables.get("accessToken").add(this.accessToken);} return (A) this;
    }

    public java.lang.Boolean hasAccessToken() {
        return this.accessToken != null;
    }

    public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluent.AccessTokenNested<A> withNewAccessToken() {
        return new io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluentImpl.AccessTokenNestedImpl();
    }

    public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluent.AccessTokenNested<A> withNewAccessTokenLike(io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSource item) {
        return new io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluentImpl.AccessTokenNestedImpl(item);
    }

    public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluent.AccessTokenNested<A> editAccessToken() {
        return withNewAccessTokenLike(getAccessToken());
    }

    public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluent.AccessTokenNested<A> editOrNewAccessToken() {
        return withNewAccessTokenLike(getAccessToken() != null ? getAccessToken(): new io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSourceBuilder().build());
    }

    public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluent.AccessTokenNested<A> editOrNewAccessTokenLike(io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSource item) {
        return withNewAccessTokenLike(getAccessToken() != null ? getAccessToken(): item);
    }

    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildSubject instead.
     * @return The buildable object.
     */
        public io.fabric8.knative.internal.pkg.tracker.Reference getSubject() {
        return this.subject!=null?this.subject.build():null;
    }

    public io.fabric8.knative.internal.pkg.tracker.Reference buildSubject() {
        return this.subject!=null?this.subject.build():null;
    }

    public A withSubject(io.fabric8.knative.internal.pkg.tracker.Reference subject) {
        _visitables.get("subject").remove(this.subject);
        if (subject!=null){ this.subject= new io.fabric8.knative.internal.pkg.tracker.ReferenceBuilder(subject); _visitables.get("subject").add(this.subject);} return (A) this;
    }

    public java.lang.Boolean hasSubject() {
        return this.subject != null;
    }

    public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluent.SubjectNested<A> withNewSubject() {
        return new io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluentImpl.SubjectNestedImpl();
    }

    public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluent.SubjectNested<A> withNewSubjectLike(io.fabric8.knative.internal.pkg.tracker.Reference item) {
        return new io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluentImpl.SubjectNestedImpl(item);
    }

    public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluent.SubjectNested<A> editSubject() {
        return withNewSubjectLike(getSubject());
    }

    public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluent.SubjectNested<A> editOrNewSubject() {
        return withNewSubjectLike(getSubject() != null ? getSubject(): new io.fabric8.knative.internal.pkg.tracker.ReferenceBuilder().build());
    }

    public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluent.SubjectNested<A> editOrNewSubjectLike(io.fabric8.knative.internal.pkg.tracker.Reference item) {
        return withNewSubjectLike(getSubject() != null ? getSubject(): item);
    }

    public boolean equals(java.lang.Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        GitLabBindingSpecFluentImpl that = (GitLabBindingSpecFluentImpl) o;
        if (accessToken != null ? !accessToken.equals(that.accessToken) :that.accessToken != null) return false;
        if (subject != null ? !subject.equals(that.subject) :that.subject != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(accessToken,  subject,  super.hashCode());
    }

    public class AccessTokenNestedImpl<N> extends io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSourceFluentImpl<io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluent.AccessTokenNested<N>> implements io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluent.AccessTokenNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSourceBuilder builder;

            AccessTokenNestedImpl(io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSource item) {
                this.builder = new io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSourceBuilder(this, item);
                        
            }

            AccessTokenNestedImpl() {
                this.builder = new io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.SecretValueFromSourceBuilder(this);
                        
            }

            public N and() {
                return (N) GitLabBindingSpecFluentImpl.this.withAccessToken(builder.build());
            }

            public N endAccessToken() {
                return and();
            }
    }


    public class SubjectNestedImpl<N> extends io.fabric8.knative.internal.pkg.tracker.ReferenceFluentImpl<io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluent.SubjectNested<N>> implements io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.GitLabBindingSpecFluent.SubjectNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final io.fabric8.knative.internal.pkg.tracker.ReferenceBuilder builder;

            SubjectNestedImpl(io.fabric8.knative.internal.pkg.tracker.Reference item) {
                this.builder = new io.fabric8.knative.internal.pkg.tracker.ReferenceBuilder(this, item);
                        
            }

            SubjectNestedImpl() {
                this.builder = new io.fabric8.knative.internal.pkg.tracker.ReferenceBuilder(this);
                        
            }

            public N and() {
                return (N) GitLabBindingSpecFluentImpl.this.withSubject(builder.build());
            }

            public N endSubject() {
                return and();
            }
    }


}
